@@ -284,113 +284,6 @@ func TestUpdateSubscriptions(t *testing.T) {
 	}
 }
 
-// Test The Dispatcher's ConfigChanged Functionality
-func TestConfigChanged(t *testing.T) {
-
-	logger := logtesting.TestLogger(t)
-	ctx := logging.WithLogger(context.TODO(), logger)
-
-	// Setup Test Environment Namespaces
-	commontesting.SetTestEnvironment(t)
-
-	// Test Data
-	brokers := []string{configtesting.DefaultKafkaBroker}
-	baseSaramaConfig, err := commonclient.NewConfigBuilder().
-		WithDefaults().
-		FromYaml(clienttesting.DefaultSaramaConfigYaml).
-		WithVersion(&sarama.V2_0_0_0).
-		Build(ctx)
-	assert.Nil(t, err)
-
-	// Define The TestCase Struct
-	type TestCase struct {
-		only                bool
-		name                string
-		newConfigMap        *corev1.ConfigMap
-		expectNewDispatcher bool
-	}
-
-	// Create The TestCases
-	testCases := []TestCase{
-		{
-			name:                "No Changes (Same Dispatcher)",
-			newConfigMap:        configtesting.NewKafkaConfigMap(),
-			expectNewDispatcher: false,
-		},
-		{
-			name:                "No EventingKafka Config (Same Dispatcher)",
-			newConfigMap:        configtesting.NewKafkaConfigMap(configtesting.WithoutEventingKafkaConfiguration),
-			expectNewDispatcher: false,
-		},
-		{
-			name:                "Admin Change (New Dispatcher)",
-			newConfigMap:        configtesting.NewKafkaConfigMap(configtesting.WithModifiedSaramaAdmin),
-			expectNewDispatcher: true,
-		},
-		{
-			name:                "Net Change (New Dispatcher)",
-			newConfigMap:        configtesting.NewKafkaConfigMap(configtesting.WithModifiedSaramaNet),
-			expectNewDispatcher: true,
-		},
-		{
-			name:                "Metadata Change (New Dispatcher)",
-			newConfigMap:        configtesting.NewKafkaConfigMap(configtesting.WithModifiedSaramaMetadata),
-			expectNewDispatcher: true,
-		},
-		{
-			name:                "Consumer Change (New Dispatcher)",
-			newConfigMap:        configtesting.NewKafkaConfigMap(configtesting.WithModifiedSaramaConsumer),
-			expectNewDispatcher: true,
-		},
-		{
-			name:                "Producer Change (Same Dispatcher)",
-			newConfigMap:        configtesting.NewKafkaConfigMap(configtesting.WithModifiedSaramaProducer),
-			expectNewDispatcher: false,
-		},
-	}
-
-	// Filter To Those With "only" Flag (If Any Specified)
-	filteredTestCases := make([]TestCase, 0)
-	for _, testCase := range testCases {
-		if testCase.only {
-			filteredTestCases = append(filteredTestCases, testCase)
-		}
-	}
-	if len(filteredTestCases) == 0 {
-		filteredTestCases = testCases
-	}
-
-	// Make Sure To Restore The NewConsumerGroup Wrapper After The Test
-	defer consumertesting.RestoreNewConsumerGroupFn()
-
-	// Run The Filtered TestCases
-	for _, testCase := range filteredTestCases {
-		t.Run(testCase.name, func(t *testing.T) {
-
-			// Mock The SyncProducer & Stub The NewConsumerGroupWrapper()
-			mockConsumerGroup := consumertesting.NewMockConsumerGroup()
-			consumertesting.StubNewConsumerGroupFn(consumertesting.NonValidatingNewConsumerGroupFn(mockConsumerGroup))
-
-			// Create A Test Dispatcher To Perform Tests Against
-			dispatcher := createTestDispatcher(t, brokers, baseSaramaConfig)
-
-			// Perform The Test
-			newDispatcher := dispatcher.ConfigChanged(ctx, testCase.newConfigMap)
-
-			// Verify Expected State (Not Much To Verify Due To Interface)
-			assert.Equal(t, testCase.expectNewDispatcher, newDispatcher != nil)
-
-			if testCase.expectNewDispatcher {
-				// Verify that the new dispatcher's channels are not the same as the original
-				oldImpl := dispatcher.(*DispatcherImpl)
-				newImpl := newDispatcher.(*DispatcherImpl)
-				assert.NotEqual(t, oldImpl.MetricsStopChan, newImpl.MetricsStopChan)
-				assert.NotEqual(t, oldImpl.MetricsStoppedChan, newImpl.MetricsStoppedChan)
-			}
-		})
-	}
-}
-
 // Test The Dispatcher's SecretChanged Functionality
 func TestSecretChanged(t *testing.T) {
 
