@@ -29,15 +29,15 @@ import (
 	"go.opencensus.io/trace"
 	"go.uber.org/zap"
 	corev1 "k8s.io/api/core/v1"
-	"knative.dev/eventing-kafka/pkg/channel/distributed/common/config"
+	distributedcommonconfig "knative.dev/eventing-kafka/pkg/channel/distributed/common/config"
 	"knative.dev/eventing-kafka/pkg/channel/distributed/common/kafka/producer"
 	kafkasarama "knative.dev/eventing-kafka/pkg/channel/distributed/common/kafka/sarama"
-	"knative.dev/eventing-kafka/pkg/channel/distributed/common/metrics"
 	"knative.dev/eventing-kafka/pkg/channel/distributed/receiver/constants"
 	"knative.dev/eventing-kafka/pkg/channel/distributed/receiver/health"
 	"knative.dev/eventing-kafka/pkg/channel/distributed/receiver/util"
 	"knative.dev/eventing-kafka/pkg/common/client"
-	commonconstants "knative.dev/eventing-kafka/pkg/common/constants"
+	commonconfig "knative.dev/eventing-kafka/pkg/common/config"
+	"knative.dev/eventing-kafka/pkg/common/metrics"
 	"knative.dev/eventing-kafka/pkg/common/tracing"
 	eventingChannel "knative.dev/eventing/pkg/channel"
 )
@@ -124,8 +124,12 @@ func (p *Producer) ProduceKafkaMessage(ctx context.Context, channelReference eve
 
 	// Produce The Kafka Message To The Kafka Topic
 	if logger.Core().Enabled(zap.DebugLevel) {
-		// Checked Logging Level First To Avoid Calling zap.Any In Production
-		logger.Debug("Producing Kafka Message", zap.Any("Headers", producerMessage.Headers), zap.Any("Message", producerMessage.Value))
+		// Checked Logging Level First To Avoid Calling StringifyHeaders and Encode Functions In Production
+		// There isn't actually any way for the sarama ByteEncoder to return an error and this is debug logging, so ignore the return value
+		msgBytes, _ := producerMessage.Value.Encode()
+		logger.Debug("Producing Kafka Message",
+			zap.Any("Headers", kafkasarama.StringifyHeaders(producerMessage.Headers)), // Log human-readable strings, not base64
+			zap.ByteString("Message", msgBytes))
 	}
 	partition, offset, err := p.kafkaProducer.SendMessage(producerMessage)
 	if err != nil {
@@ -143,6 +147,8 @@ func (p *Producer) ObserveMetrics(interval time.Duration) {
 	// Fork A New Process To Run Async Metrics Collection
 	go func() {
 
+		metricsTimer := time.NewTimer(interval)
+
 		// Infinite Loop For Periodically Observing Sarama Metrics From Registry
 		for {
 
@@ -153,82 +159,20 @@ func (p *Producer) ObserveMetrics(interval time.Duration) {
 				close(p.metricsStoppedChan)
 				return
 
-			case <-time.After(interval):
+			case <-metricsTimer.C:
 				// Get All The Sarama Metrics From The Producer's Metrics Registry
 				kafkaMetrics := p.metricsRegistry.GetAll()
 
 				// Forward Metrics To Prometheus For Observation
 				p.statsReporter.Report(kafkaMetrics)
+
+				// Schedule Another Report
+				metricsTimer.Reset(interval)
 			}
 		}
 	}()
 }
 
-// ConfigChanged is called by the configMapObserver handler function in main() so that
-// settings specific to the producer may be extracted and the producer restarted if necessary.
-// The new configmap could technically have changes to the eventing-kafka section as well as the sarama
-// section, but none of those matter to a currently-running Producer, so those are ignored here
-// (which avoids the necessity of calling env.GetEnvironment).  If those settings
-// are needed in the future, the environment will also need to be re-parsed here.
-// If there aren't any producer-specific differences between the current config and the new one,
-// then just log that and move on; do not restart the Producer unnecessarily.
-func (p *Producer) ConfigChanged(ctx context.Context, configMap *corev1.ConfigMap) *Producer {
-
-	p.logger.Debug("New ConfigMap Received", zap.String("configMap.Name", configMap.ObjectMeta.Name))
-
-	// Validate Configuration (Should Always Be Present)
-	if p.configuration == nil {
-		p.logger.Error("Producer configuration is nil; cannot reconfigure")
-		return nil
-	}
-
-	// Validate The ConfigMap Data
-	if configMap.Data == nil {
-		p.logger.Error("Attempted to merge sarama settings with empty configmap")
-		return nil
-	}
-
-	// Merge The ConfigMap Settings Into The Provided Config
-	saramaSettingsYamlString := configMap.Data[commonconstants.SaramaSettingsConfigKey]
-
-	// Merge The Sarama Config From ConfigMap Into New Sarama Config
-	configBuilder := client.NewConfigBuilder().
-		WithDefaults().
-		FromYaml(saramaSettingsYamlString)
-
-	// Some of the current config settings may not be overridden by the configmap (username, password, etc.)
-	configBuilder = configBuilder.
-		WithClientId(p.configuration.ClientID).
-		WithAuth(kafkasarama.AuthFromSarama(p.configuration))
-
-	newConfig, err := configBuilder.Build(ctx)
-	if err != nil {
-		p.logger.Error("Unable to merge sarama settings", zap.Error(err))
-		return nil
-	}
-
-	ekConfig, err := kafkasarama.LoadEventingKafkaSettings(configMap)
-	if err != nil || ekConfig == nil {
-		p.logger.Error("Could Not Extract Eventing-Kafka Setting From Updated ConfigMap", zap.Error(err))
-		return nil
-	}
-
-	// Enable Sarama Logging If Specified In ConfigMap
-	kafkasarama.EnableSaramaLogging(ekConfig.Kafka.EnableSaramaLogging)
-	p.logger.Debug("Updated Sarama logging", zap.Bool("Kafka.EnableSaramaLogging", ekConfig.Kafka.EnableSaramaLogging))
-
-	// Ignore the "Admin" and "Consumer" sections when comparing, as changes to those do not require restarting the Producer
-	if client.ConfigEqual(newConfig, p.configuration, newConfig.Admin, newConfig.Consumer) &&
-		client.HasSameBrokers(ekConfig.Kafka.Brokers, p.brokers) {
-		p.logger.Info("No Producer Changes Detected In New Configuration - Ignoring")
-		return nil
-	}
-
-	// Create A New Producer With The New Configuration (Reusing All Other Existing Config)
-	p.logger.Info("Producer Changes Detected In New Configuration - Closing & Recreating Producer")
-	return p.reconfigure(newConfig, ekConfig)
-}
-
 // SecretChanged is called by the secretObserver handler function in main() so that
 // settings specific to the producer may be extracted and the producer restarted if necessary.
 func (p *Producer) SecretChanged(ctx context.Context, secret *corev1.Secret) *Producer {
@@ -236,7 +180,7 @@ func (p *Producer) SecretChanged(ctx context.Context, secret *corev1.Secret) *Pr
 	// Debug Log The Secret Change
 	p.logger.Debug("New Secret Received", zap.String("secret.Name", secret.ObjectMeta.Name))
 
-	kafkaAuthCfg := config.GetAuthConfigFromSecret(secret)
+	kafkaAuthCfg := distributedcommonconfig.GetAuthConfigFromSecret(secret)
 	if kafkaAuthCfg == nil {
 		p.logger.Warn("No auth config found in secret; ignoring update")
 		return nil
@@ -284,7 +228,7 @@ func (p *Producer) Close() {
 }
 
 // Shut down the current producer and recreate it with new settings
-func (p *Producer) reconfigure(newConfig *sarama.Config, ekConfig *config.EventingKafkaConfig) *Producer {
+func (p *Producer) reconfigure(newConfig *sarama.Config, ekConfig *commonconfig.EventingKafkaConfig) *Producer {
 	p.Close()
 	if ekConfig != nil {
 		// Currently the only thing that a new producer might care about in the EventingKafkaConfig is the Brokers
